@@ -1,4 +1,9 @@
 
+__author__    = "Andre Merzky"
+__copyright__ = "Copyright 2012-2013, The SAGA Project"
+__license__   = "MIT"
+
+
 """ A collection of utilities which maps a namespace structure to redis nosql
 keys.  It mirrors the Python ``os`` API, to some extent.
 
@@ -48,14 +53,16 @@ import time
 import string
 import redis
 
+import radical.utils         as ru
+import radical.utils.logger  as rul
+import radical.utils.threads as rut
+
 import redis_cache
 
 from   saga.exceptions       import *
 from   saga.advert.constants import *
-from   saga.utils.logger     import getLogger
 
 import saga.utils.misc       as sumisc
-import saga.utils.threads    as sut
 
 
 TYPE   = 'type'
@@ -88,7 +95,7 @@ def redis_ns_name (path) :
 
 # --------------------------------------------------------------------
 #
-class redis_ns_monitor (sut.SagaThread) :
+class redis_ns_monitor (ru.Thread) :
 
     # ----------------------------------------------------------------
     #
@@ -101,7 +108,7 @@ class redis_ns_monitor (sut.SagaThread) :
         self.pat = {}
         self.pat['ATTRIBUTE'] = re.compile ('\s*\[(?P<key>[^=]+)=(?P<val>.+)]\s*')
 
-        sut.SagaThread.__init__ (self, self.work)
+        rut.Thread.__init__ (self, self.work)
         self.setDaemon (True)
 
 
@@ -201,7 +208,7 @@ class redis_ns_server (redis.Redis) :
         t2 = time.time ()
 
         # add a logger 
-        self.logger = getLogger ("redis-%s"  % self.host)
+        self.logger = rul.getLogger ('saga', "redis-%s"  % self.host)
 
         # create a cache dict and attach to redis client instance.  Cache
         # lifetime is set to 10 times the redis-connect latency.
@@ -653,5 +660,5 @@ class redis_ns_entry :
 
   
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
