@@ -1,4 +1,9 @@
 
+__author__    = "Andre Merzky, Ole Weidner, Alexander Grill"
+__copyright__ = "Copyright 2012-2013, The SAGA Project"
+__license__   = "MIT"
+
+
 """ shell based file adaptor implementation """
 
 import saga.utils.pty_shell as sups
@@ -163,7 +168,7 @@ class Adaptor (saga.adaptors.base.Base):
         saga.adaptors.base.Base.__init__ (self, _ADAPTOR_INFO, _ADAPTOR_OPTIONS)
 
         self.id_re = re.compile ('^\[(.*)\]-\[(.*?)\]$')
-        self.opts  = self.get_config ()
+        self.opts  = self.get_config (_ADAPTOR_NAME)
 
         self.notifications = self.opts['enable_notifications'].get_value ()
 
@@ -201,7 +206,7 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
     #
     def _is_valid (self) :
 
-        if not self.valid :
+        if  not self.valid :
             raise saga.IncorrectState ("this instance was closed or removed")
 
     # ----------------------------------------------------------------
@@ -210,7 +215,7 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
 
         dirname = sumisc.url_get_dirname (tgt)
 
-        if sumisc.url_is_compatible (cwdurl, tgt) :
+        if  sumisc.url_is_compatible (cwdurl, tgt) :
 
             ret, out, _ = self.shell.run_sync ("mkdir -p %s\n" % (dirname))
             if  ret != 0 :
@@ -219,7 +224,7 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
 
         elif sumisc.url_is_local (tgt) :
 
-            if tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
+            if  tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
                 raise saga.BadParameter ("schema of mkdir target is not supported (%s)" \
                                       % (tgt))
 
@@ -239,6 +244,9 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
     def init_instance (self, adaptor_state, url, flags, session) :
         """ Directory instance constructor """
 
+        if  flags == None :
+            flags = 0
+
         self.url         = saga.Url (url) # deep copy
         self.flags       = flags
         self.session     = session
@@ -299,7 +307,6 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
         if  kill and self.shell :
             self.shell.finalize (True)
             self.shell = None
-
         self.valid = False
 
 
@@ -323,13 +330,40 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
         adaptor_state = { "from_open" : True,
                           "cwd"       : saga.Url(self.url) }  # deep copy
 
-        if sumisc.url_is_relative (url) :
+        if  sumisc.url_is_relative (url) :
             url = sumisc.url_make_absolute (self.get_url (), url)
 
         return saga.filesystem.File (url=url, flags=flags, session=self.session, 
                                      _adaptor=self._adaptor, _adaptor_state=adaptor_state)
 
 
+    # ----------------------------------------------------------------
+    #
+    @SYNC_CALL
+    def open_dir (self, url, flags) :
+
+        self._is_valid ()
+
+        adaptor_state = { "from_open" : True,
+                          "cwd"       : saga.Url(self.url) }  # deep copy
+
+        if  sumisc.url_is_relative (url) :
+            url = sumisc.url_make_absolute (self.get_url (), url)
+
+        return saga.filesystem.Directory (url=url, flags=flags, session=self.session, 
+                                          _adaptor=self._adaptor, _adaptor_state=adaptor_state)
+
+    # ----------------------------------------------------------------
+    #
+    @SYNC_CALL
+    def close (self, timeout=None):
+
+        if  timeout :
+            raise saga.BadParameter ("timeout for close not supported")
+
+        self.finalize (kill=True)
+
+
     # ----------------------------------------------------------------
     @SYNC_CALL
     def get_url (self) :
@@ -349,9 +383,12 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
         # FIXME: eval flags
 
         if  None == npat :
-            npat = "*"
+            npat = ""
+        else :
+            npat = "-d %s" % npat
+
+        ret, out, _ = self.shell.run_sync ("/bin/ls -C1 %s\n" % npat)
 
-        ret, out, _ = self.shell.run_sync ("/bin/ls -C1 -d %s\n" % npat)
         if  ret != 0 :
             raise saga.NoSuccess ("failed to list(): (%s)(%s)" \
                                % (ret, out))
@@ -382,7 +419,7 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
     # ----------------------------------------------------------------
     #
     @SYNC_CALL
-    def copy (self, src_in, tgt_in, flags):
+    def copy (self, src_in, tgt_in, flags, _from_task=None):
 
         self._is_valid ()
 
@@ -392,20 +429,17 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
         src    = saga.Url (src_in)   # deep copy
         tgt    = saga.Url (tgt_in)   # deep copy
 
-        if sumisc.url_is_relative (src) : src = sumisc.url_make_absolute (cwdurl, src)
-        if sumisc.url_is_relative (tgt) : tgt = sumisc.url_make_absolute (cwdurl, tgt)
-
+      # if  sumisc.url_is_relative (src) : src = sumisc.url_make_absolute (cwdurl, src)
+      # if  sumisc.url_is_relative (tgt) : tgt = sumisc.url_make_absolute (cwdurl, tgt)
+    
         rec_flag = ""
-        if flags & saga.filesystem.RECURSIVE : 
+        if  flags & saga.filesystem.RECURSIVE : 
             rec_flag  += "-r "
 
-        if flags & saga.filesystem.CREATE_PARENTS : 
+        if  flags & saga.filesystem.CREATE_PARENTS : 
             self._create_parent (cwdurl, tgt)
 
-
-        # print cwdurl
-        # print src
-        # print tgt
+        files_copied = list()
 
         # if cwd, src and tgt point to the same host, we just run a shell cp
         # command on that host
@@ -413,10 +447,10 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
             sumisc.url_is_compatible (cwdurl, tgt) :
 
             # print "shell cp"
-            ret, out, _ = self.shell.run_sync ("cp %s %s %s\n" % (rec_flag, src.path, tgt.path))
+            ret, out, err = self.shell.run_sync ("cp %s %s %s\n" % (rec_flag, src.path, tgt.path))
             if  ret != 0 :
-                raise saga.NoSuccess ("copy (%s -> %s) failed (%s): (%s)" \
-                                   % (src, tgt, ret, out))
+                raise saga.NoSuccess ("copy (%s -> %s) failed (%s): (out: %s) (err: %s)" \
+                                   % (src, tgt, ret, out, err))
 
 
         # src and tgt are on different hosts, we need to find out which of them
@@ -425,21 +459,21 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
             # print "! shell cp"
 
             # if cwd is remote, we use stage from/to
-            if not sumisc.url_is_local (cwdurl) :
+            if  not sumisc.url_is_local (cwdurl) :
 
                 # print "cwd remote"
 
-                if sumisc.url_is_local (src)          and \
-                   sumisc.url_is_compatible (cwdurl, tgt) :
+                if  sumisc.url_is_local (src)          and \
+                    sumisc.url_is_compatible (cwdurl, tgt) :
 
                     # print "from local to remote"
-                    self.shell.stage_to_remote (src.path, tgt.path, rec_flag)
+                    files_copied = self.shell.stage_to_remote (src.path, tgt.path, rec_flag)
 
                 elif sumisc.url_is_local (tgt)          and \
                      sumisc.url_is_compatible (cwdurl, src) :
 
                     # print "from remote to loca"
-                    self.shell.stage_from_remote (src.path, tgt.path, rec_flag)
+                    files_copied = self.shell.stage_from_remote (src.path, tgt.path, rec_flag)
 
                 else :
                     # print "from remote to other remote -- fail"
@@ -455,27 +489,27 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
 
                 # print "cwd local"
 
-                if sumisc.url_is_local (src) :
+                if  sumisc.url_is_local (src) :
 
                     # need a compatible target scheme
-                    if tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
+                    if  tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
                         raise saga.BadParameter ("schema of copy target is not supported (%s)" \
                                               % (tgt))
 
                     # print "from local to remote"
-                    tmp_shell = sups.PTYShell (tgt, self.session, self._logger)
-                    tmp_shell.stage_to_remote (src.path, tgt.path, rec_flag)
+                    tmp_shell    = sups.PTYShell (tgt, self.session, self._logger)
+                    files_copied = tmp_shell.stage_to_remote (src.path, tgt.path, rec_flag)
 
                 elif sumisc.url_is_local (tgt) :
 
                     # need a compatible source scheme
-                    if src.scheme and not src.scheme.lower () in _ADAPTOR_SCHEMAS :
+                    if  src.scheme and not src.scheme.lower () in _ADAPTOR_SCHEMAS :
                         raise saga.BadParameter ("schema of copy source is not supported (%s)" \
                                               % (src))
 
                     # print "from remote to local"
-                    tmp_shell = sups.PTYShell (src, self.session, self._logger)
-                    tmp_shell.stage_from_remote (src.path, tgt.path, rec_flag)
+                    tmp_shell    = sups.PTYShell (src, self.session, self._logger)
+                    files_copied = tmp_shell.stage_from_remote (src.path, tgt.path, rec_flag)
 
                 else :
 
@@ -485,6 +519,8 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
                                           % (src, tgt))
 
    
+        if  _from_task :
+            _from_task._set_metric ('files_copied', files_copied)
 
 
     # ----------------------------------------------------------------
@@ -540,18 +576,18 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
         cwdurl = saga.Url (self.url) # deep copy
         tgt    = saga.Url (tgt_in)   # deep copy
 
-        if sumisc.url_is_relative (tgt) : tgt = sumisc.url_make_absolute (cwdurl, tgt)
+        # if sumisc.url_is_relative (tgt) : tgt = sumisc.url_make_absolute (cwdurl, tgt)
 
         rec_flag = ""
-        if flags & saga.filesystem.RECURSIVE : 
+        if  flags & saga.filesystem.RECURSIVE : 
             rec_flag  += "-r "
 
         if  sumisc.url_is_compatible (cwdurl, tgt) :
 
-            ret, out, _ = self.shell.run_sync ("rm %s %s\n" % (rec_flag, tgt.path))
+            ret, out, err = self.shell.run_sync ("rm -f %s %s\n" % (rec_flag, tgt.path))
             if  ret != 0 :
-                raise saga.NoSuccess ("remove (%s) failed (%s): (%s)" \
-                                   % (tgt, ret, out))
+                raise saga.NoSuccess ("remove (%s) failed (%s): (out: %s) (err: %s)" \
+                                   % (tgt, ret, out, err))
 
 
         # we cannot support the URL
@@ -608,7 +644,7 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
         cwdurl = saga.Url (self.url) # deep copy
         tgt    = saga.Url (tgt_in)   # deep copy
 
-        tgt_abs = sumisc.url_make_absolute (cwdurl, tgt)
+        # tgt_abs = sumisc.url_make_absolute (cwdurl, tgt)
 
         ret, out, _ = self.shell.run_sync ("du -ks %s  | xargs | cut -f 1 -d ' '\n" % tgt.path)
         if  ret != 0 :
@@ -718,7 +754,7 @@ class ShellDirectory (saga.adaptors.cpi.filesystem.Directory) :
     @SYNC_CALL
     def is_file (self, tgt_in):
 
-        return self.is_file (tgt_in)
+        return self.is_entry (tgt_in)
    
    
 ###############################################################################
@@ -745,7 +781,7 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
     #
     def _is_valid (self) :
 
-        if not self.valid :
+        if  not self.valid :
             raise saga.IncorrectState ("this instance was closed or removed")
 
     # ----------------------------------------------------------------
@@ -754,7 +790,7 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
 
         dirname = sumisc.url_get_dirname (tgt)
 
-        if sumisc.url_is_compatible (cwdurl, tgt) :
+        if  sumisc.url_is_compatible (cwdurl, tgt) :
 
             ret, out, _ = self.shell.run_sync ("mkdir -p %s\n" % (dirname))
             if  ret != 0 :
@@ -763,7 +799,7 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
 
         elif sumisc.url_is_local (tgt) :
 
-            if tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
+            if  tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
                 raise saga.BadParameter ("schema of mkdir target is not supported (%s)" \
                                       % (tgt))
 
@@ -773,8 +809,9 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
                                    % (dirname, ret, out))
 
         else :
-            raise saga.BadParameter ("failed: cannot create target dir for '%s': (%s) (%s)" \
-                                  % (tgt, ret, out))
+
+            raise saga.BadParameter ("failed: cannot create target dir '%s': not local to pwd (%s)" \
+                                  % (tgt, cwdurl))
 
 
     # ----------------------------------------------------------------
@@ -783,6 +820,8 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
     def init_instance (self, adaptor_state, url, flags, session):
 
         # FIXME: eval flags!
+        if  flags == None :
+            flags = 0
 
         self._logger.info ("init_instance %s" % url)
 
@@ -864,7 +903,7 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
         ret, out, _ = self.shell.run_sync (cmd)
 
         if  ret != 0 :
-            if self.flags & saga.filesystem.CREATE_PARENTS :
+            if  self.flags & saga.filesystem.CREATE_PARENTS :
                 raise saga.BadParameter ("cannot open/create: '%s' - %s" % (self.url.path, out))
             elif self.flags & saga.filesystem.CREATE :
                 raise saga.BadParameter ("cannot open/create: '%s' - %s" % (self.url.path, out))
@@ -878,7 +917,7 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
 
     # ----------------------------------------------------------------
     #
-    def finalize (self, kill = False) :
+    def finalize (self, kill=False) :
 
         if  kill and self.shell :
             self.shell.finalize (True)
@@ -891,6 +930,17 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
         self.valid = False
 
 
+    # ----------------------------------------------------------------
+    #
+    @SYNC_CALL
+    def close (self, timeout=None):
+
+        if  timeout :
+            raise saga.BadParameter ("timeout for close not supported")
+
+        self.finalize (kill=True)
+
+
     # ----------------------------------------------------------------
     #
     @SYNC_CALL
@@ -916,20 +966,16 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
         src    = saga.Url (self.url)    # deep copy
         tgt    = saga.Url (tgt_in)      # deep copy
 
-        if sumisc.url_is_relative (src) : src = sumisc.url_make_absolute (cwdurl, src)
-        if sumisc.url_is_relative (tgt) : tgt = sumisc.url_make_absolute (cwdurl, tgt)
+        # if sumisc.url_is_relative (src) : src = sumisc.url_make_absolute (cwdurl, src)
+        # if sumisc.url_is_relative (tgt) : tgt = sumisc.url_make_absolute (cwdurl, tgt)
 
         rec_flag = ""
-        if flags & saga.filesystem.RECURSIVE : 
+        if  flags & saga.filesystem.RECURSIVE : 
             rec_flag  += "-r "
 
-        if flags & saga.filesystem.CREATE_PARENTS : 
+        if  flags & saga.filesystem.CREATE_PARENTS : 
             self._create_parent (cwdurl, tgt)
 
-        # print cwdurl
-        # print src
-        # print tgt
-
         # if cwd, src and tgt point to the same host, we just run a shell cp
         # command on that host
         if  sumisc.url_is_compatible (cwdurl, src) and \
@@ -948,21 +994,21 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
             # print "! shell cp"
 
             # if cwd is remote, we use stage from/to on the existing pipe
-            if not sumisc.url_is_local (cwdurl) :
+            if  not sumisc.url_is_local (cwdurl) :
 
                 # print "cwd remote"
 
-                if sumisc.url_is_local (src)          and \
-                   sumisc.url_is_compatible (cwdurl, tgt) :
+                if  sumisc.url_is_local (src)          and \
+                    sumisc.url_is_compatible (cwdurl, tgt) :
 
                     # print "from local to remote"
-                    self.shell.stage_to_remote (src.path, tgt.path, rec_flag)
+                    files_copied = self.shell.stage_to_remote (src.path, tgt.path, rec_flag)
 
                 elif sumisc.url_is_local (tgt)          and \
                      sumisc.url_is_compatible (cwdurl, src) :
 
                     # print "from remote to loca"
-                    self.shell.stage_from_remote (src.path, tgt.path, rec_flag)
+                    files_copied = self.shell.stage_from_remote (src.path, tgt.path, rec_flag)
 
                 else :
                     # print "from remote to other remote -- fail"
@@ -978,32 +1024,31 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
 
                 # print "cwd local"
 
-                if sumisc.url_is_local (src) :
+                if  sumisc.url_is_local (src) :
 
                     # need a compatible target scheme
-                    if tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
+                    if  tgt.scheme and not tgt.scheme.lower () in _ADAPTOR_SCHEMAS :
                         raise saga.BadParameter ("schema of copy target is not supported (%s)" \
                                               % (tgt))
 
                     # print "from local to remote"
-                    tmp_shell = sups.PTYShell (tgt, self.session, self._logger)
-                    tmp_shell.stage_to_remote (src.path, tgt.path, rec_flag)
+                    tmp_shell    = sups.PTYShell (tgt, self.session, self._logger)
+                    files_copied = tmp_shell.stage_to_remote (src.path, tgt.path, rec_flag)
 
                 elif sumisc.url_is_local (tgt) :
 
                     # need a compatible source scheme
-                    if src.scheme and not src.scheme.lower () in _ADAPTOR_SCHEMAS :
+                    if  src.scheme and not src.scheme.lower () in _ADAPTOR_SCHEMAS :
                         raise saga.BadParameter ("schema of copy source is not supported (%s)" \
                                               % (src))
 
                     # print "from remote to local"
-                    tmp_shell = sups.PTYShell (src, self.session, self._logger)
-                    tmp_shell.stage_from_remote (src.path, tgt.path, rec_flag)
+                    tmp_shell    = sups.PTYShell (src, self.session, self._logger)
+                    files_copied = tmp_shell.stage_from_remote (src.path, tgt.path, rec_flag)
 
                 else :
 
-                    # print "from remote to other remote -- fail"
-                    # we cannot support the combination of URLs
+                    # we cannot support two remote URLs
                     raise saga.BadParameter ("copy from %s to %s is not supported" \
                                           % (src, tgt))
 
@@ -1015,13 +1060,65 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
 
         # we handle move non-atomically, i.e. as copy/remove
         self.copy_self   (tgt_in, flags)
-        self.remove_self (tgt_in, flags)
+        self.remove_self (flags)
 
         # however, we are not closed at this point, but need to re-initialize
         self.url   = tgt_in
         self.flags = flags
         self.initialize ()
 
+    # ----------------------------------------------------------------
+    #
+    @SYNC_CALL
+    def write (self, string, flags=None):
+	"""
+	This call is intended to write a string to a local or remote file.
+	Since write() uses file staging calls, it cannot be used to randomly
+	write certain parts of a file (i.e. seek()). Together with read(),
+	it was designed to manipulate template files and write them back to
+	the remote directory. Be aware, that writing large files will
+	be very slow compared to native read(2) and write(2) calls.
+	"""
+        self._is_valid ()
+        if  flags==None:
+            flags = self.flags
+        else:
+            self.flags=flags
+
+        tgt = saga.Url (self.url)  # deep copy, is absolute
+            
+        if  flags==saga.filesystem.APPEND:
+            string = self.read()+string            
+        # FIXME: eval flags
+
+        self.shell.write_to_remote(string,tgt.path)
+                                                    
+    # ----------------------------------------------------------------
+    #
+    @SYNC_CALL
+    def read (self,size=None):
+	"""
+	This call is intended to read a string wit length size from a local
+	or remote file.	Since read() uses file staging calls, it cannot be
+	used to randomly read certain parts of a file (i.e. seek()).
+	Together with write(), it was designed to manipulate template files
+	and write them back to the remote directory. Be aware, that reading
+	large files will be very slow compared to native read(2) and write(2)
+	calls.
+	"""
+
+        self._is_valid ()
+
+        tgt = saga.Url (self.url)  # deep copy, is absolute
+        
+        out = self.shell.read_from_remote(tgt.path)
+
+        if  size!=None:
+            return out[0:size-1]
+        else:
+            return out
+
+
    
     # ----------------------------------------------------------------
     #
@@ -1036,10 +1133,10 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
         tgt = saga.Url (self.url)  # deep copy, is absolute
 
         rec_flag = ""
-        if flags & saga.filesystem.RECURSIVE : 
+        if  flags & saga.filesystem.RECURSIVE : 
             rec_flag  += "-r "
 
-        ret, out, _ = self.shell.run_sync ("rm %s %s\n" % (rec_flag, tgt.path))
+        ret, out, _ = self.shell.run_sync ("rm -f %s %s\n" % (rec_flag, tgt.path))
         if  ret != 0 :
             raise saga.NoSuccess ("remove (%s) failed (%s): (%s)" \
                                % (tgt, ret, out))
@@ -1051,17 +1148,28 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
     def get_size_self (self) :
 
         self._is_valid ()
+        size      = None
+        size_mult = 1
+        ret       = None
+        out       = None
+
+        if  self.is_dir_self () :
+            size_mult   = 1024   # see '-k' option to 'du'
+            ret, out, _ = self.shell.run_sync ("du -ks %s  | xargs | cut -f 1 -d ' '\n" \
+                                            % self.url.path)
+        else :
+            ret, out, _ = self.shell.run_sync ("wc -c %s | xargs | cut -f 1 -d ' '\n" \
+                                            % self.url.path)
 
-        ret, out, _ = self.shell.run_sync ("wc -c %s | xargs | cut -f 1 -d ' '\n" % self.url.path)
         if  ret != 0 :
             raise saga.NoSuccess ("get size for (%s) failed (%s): (%s)" \
                                % (self.url, ret, out))
 
-        size = None
         try :
-            size = int (out)
+            size = int (out) * size_mult
         except Exception as e :
-            raise saga.NoSuccess ("get size for (%s) failed: (%s)" % (self.url, out))
+            raise saga.NoSuccess ("could not get file size: %s" % out)
+
 
         return size
    
@@ -1123,5 +1231,5 @@ class ShellFile (saga.adaptors.cpi.filesystem.File) :
    
    
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
