@@ -6,10 +6,11 @@ __license__   = "MIT"
 
 """ SAGA job interface """
 
+import radical.utils.signatures as rus
+
 from   saga.constants        import SYNC, ASYNC, TASK
 from   saga.job.constants    import *
 
-import saga.utils.signatures as sus
 import saga.adaptors.base    as sab
 import saga.attributes       as sa
 import saga.exceptions       as se
@@ -52,12 +53,12 @@ class Job (sb.Base, st.Task, sasync.Async) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
-                  sus.optional (basestring),
-                  sus.optional (sab.Base),
-                  sus.optional (dict),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (sus.nothing)
+    @rus.takes   ('Job',
+                  rus.optional (basestring),
+                  rus.optional (sab.Base),
+                  rus.optional (dict),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (rus.nothing)
     def __init__ (self, _method_type='run', _adaptor=None, _adaptor_state={}, _ttype=None) : 
         '''
         _adaptor`` references the adaptor class instance which created this task
@@ -124,8 +125,8 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job')
-    @sus.returns (basestring)
+    @rus.takes   ('Job')
+    @rus.returns (basestring)
     def __str__  (self) :
         """
         __str__()
@@ -141,9 +142,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, basestring, st.Task))
+    @rus.takes   ('Job',
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, basestring, st.Task))
     def get_id   (self, ttype=None) :
         """
         get_id()
@@ -156,9 +157,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes          ('Job',
-                         sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns        ((basestring, st.Task))
+    @rus.takes          ('Job',
+                         rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns        ((basestring, st.Task))
     def get_description (self, ttype=None) :
         """
         get_description()
@@ -196,9 +197,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes    ('Job',
-                   sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns  ((file, st.Task))
+    @rus.takes    ('Job',
+                   rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns  ((file, st.Task))
     def get_stdin (self, ttype=None) :
         """
         get_stdin()
@@ -210,9 +211,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job',
-                    sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns   ((file, st.Task))
+    @rus.takes     ('Job',
+                    rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns   ((file, st.Task))
     def get_stdout (self, ttype=None) :
         """
         get_stdout()
@@ -224,9 +225,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job',
-                    sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns   ((file, st.Task))
+    @rus.takes     ('Job',
+                    rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns   ((file, st.Task))
     def get_stderr (self, ttype=None) :
         """
         get_stderr()
@@ -241,9 +242,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+    @rus.takes   ('Job',
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def suspend  (self, ttype=None) :
         """
         suspend()
@@ -255,9 +256,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+    @rus.takes   ('Job',
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def resume   (self, ttype=None) :
         """
         resume()
@@ -269,9 +270,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job',
-                    sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns   ((sus.nothing, st.Task))
+    @rus.takes     ('Job',
+                    rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns   ((rus.nothing, st.Task))
     def checkpoint (self, ttype=None) :
         """
         checkpoint()
@@ -283,10 +284,10 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
+    @rus.takes   ('Job',
                   descr.Description,
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def migrate  (self, jd, ttype=None) :
         """
         jd:        saga.job.Description  
@@ -298,10 +299,10 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
+    @rus.takes   ('Job',
                   int,
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def signal   (self, signum, ttype=None) :
         """
         signal(signum)
@@ -325,9 +326,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
     #
     # task methods flattened into job :-/
     #
-    @sus.takes   ('Job',
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+    @rus.takes   ('Job',
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def run      (self, ttype=None) :
         """
         run()
@@ -367,10 +368,10 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
+    @rus.takes   ('Job',
                   float,
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def cancel   (self, timeout=None, ttype=None) :
         """
         cancel(timeout)
@@ -413,10 +414,10 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Job',
-                  sus.optional (float),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+    @rus.takes   ('Job',
+                  rus.optional (float),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def wait     (self, timeout=None, ttype=None) :
         """
         wait(timeout)
@@ -477,9 +478,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes    ('Job',
-                   sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns  ((sus.one_of (UNKNOWN, NEW, PENDING, RUNNING, SUSPENDED, DONE, FAILED, CANCELED), st.Task))
+    @rus.takes    ('Job',
+                   rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns  ((rus.one_of (UNKNOWN, NEW, PENDING, RUNNING, SUSPENDED, DONE, FAILED, CANCELED), st.Task))
     def get_state (self, ttype=None) :
         """
         get_state()
@@ -512,9 +513,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job',
-                    sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns   ((sus.anything, st.Task))
+    @rus.takes     ('Job',
+                    rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns   ((rus.anything, st.Task))
     def get_result (self, ttype=None) :
         """
         get_result()
@@ -524,9 +525,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job',
-                    sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns   ((sb.Base, st.Task))
+    @rus.takes     ('Job',
+                    rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns   ((sb.Base, st.Task))
     def get_object (self, ttype=None) :
         """ :todo: describe me
             :note: this will return the job_service which created the job.
@@ -536,9 +537,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job',
-                    sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns   ((se.SagaException, st.Task))
+    @rus.takes     ('Job',
+                    rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns   ((se.SagaException, st.Task))
     def get_exception (self, ttype=None) :
         """ :todo: describe me
 
@@ -551,8 +552,8 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes     ('Job')
-    @sus.returns   (sus.nothing)
+    @rus.takes     ('Job')
+    @rus.returns   (rus.nothing)
     def re_raise   (self) :
         """ :todo: describe me
 
@@ -566,9 +567,9 @@ class Job (sb.Base, st.Task, sasync.Async) :
     # 
     # attribute getters
     #
-    @sus.takes         ('Job',
-                        sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns       ((sus.nothing, int, st.Task))
+    @rus.takes         ('Job',
+                        rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns       ((rus.nothing, int, st.Task))
     def _get_exit_code (self, ttype=None) :
         ec = self._adaptor.get_exit_code(ttype=ttype)
         if ec in [None, ""]:
@@ -580,41 +581,41 @@ class Job (sb.Base, st.Task, sasync.Async) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes       ('Job',
-                      sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns     ((sus.nothing, float, st.Task))
+    @rus.takes       ('Job',
+                      rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns     ((rus.nothing, float, st.Task))
     def _get_created (self, ttype=None) :
         return self._adaptor.get_created (ttype=ttype)
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes       ('Job',
-                      sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns     ((sus.nothing, float, st.Task))
+    @rus.takes       ('Job',
+                      rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns     ((rus.nothing, float, st.Task))
     def _get_started (self, ttype=None) :
         return self._adaptor.get_started (ttype=ttype)
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes       ('Job',
-                      sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns     ((sus.nothing, float, st.Task))
+    @rus.takes       ('Job',
+                      rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns     ((rus.nothing, float, st.Task))
     def _get_finished (self, ttype=None) :
         return self._adaptor.get_finished (ttype=ttype)
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes       ('Job',
-                      sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns     ((sus.nothing, sus.list_of (basestring), st.Task))
+    @rus.takes       ('Job',
+                      rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns     ((rus.nothing, rus.list_of (basestring), st.Task))
     def _get_execution_hosts (self, ttype=None) :
         return self._adaptor.get_execution_hosts (ttype=ttype)
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes       ('Job',
-                      sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns     ((sus.nothing, surl.Url, st.Task))
+    @rus.takes       ('Job',
+                      rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns     ((rus.nothing, surl.Url, st.Task))
     def _get_service_url (self, ttype=None) :
         return self._adaptor.get_service_url (ttype=ttype)
 
@@ -694,12 +695,12 @@ class Self (Job) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Self',
-                  sus.optional (basestring),
-                  sus.optional (sab.Base),
-                  sus.optional (dict),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (sus.nothing)
+    @rus.takes   ('Self',
+                  rus.optional (basestring),
+                  rus.optional (sab.Base),
+                  rus.optional (dict),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (rus.nothing)
     def __init__ (self, _method_type='run', _adaptor=None, _adaptor_state={}, _ttype=None) : 
 
     
@@ -707,5 +708,5 @@ class Self (Job) :
         self._base.__init__ (_method_type, _adaptor, _adaptor_state, _ttype=_ttype)
 
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
