@@ -1,10 +1,11 @@
 
-__author__    = "Andre Merzky"
+__author__    = "Andre Merzky, Ole Weidner, Alexander Grill"
 __copyright__ = "Copyright 2012-2013, The SAGA Project"
 __license__   = "MIT"
 
 
-import saga.utils.signatures     as sus
+import radical.utils.signatures  as rus
+
 import saga.adaptors.base        as sab
 import saga.session              as ss
 import saga.task                 as st
@@ -53,14 +54,14 @@ class Directory (entry.Entry) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int), 
-                  sus.optional (ss.Session),
-                  sus.optional (sab.Base), 
-                  sus.optional (dict), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (sus.nothing)
+    @rus.takes   ('Directory', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int), 
+                  rus.optional (ss.Session),
+                  rus.optional (sab.Base), 
+                  rus.optional (dict), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (rus.nothing)
     def __init__ (self, url=None, flags=None, session=None, 
                   _adaptor=None, _adaptor_state={}, _ttype=None) : 
         '''
@@ -96,12 +97,12 @@ class Directory (entry.Entry) :
     # --------------------------------------------------------------------------
     #
     @classmethod
-    @sus.takes   ('Directory', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int), 
-                  sus.optional (ss.Session),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (st.Task)
+    @rus.takes   ('Directory', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int), 
+                  rus.optional (ss.Session),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (st.Task)
     def create (cls, url=None, flags=None, session=None, ttype=None) :
         '''
         url:       saga.Url
@@ -117,11 +118,11 @@ class Directory (entry.Entry) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((entry.Entry, st.Task))
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((entry.Entry, st.Task))
     def open (self, name, flags=None, ttype=None) :
         '''
         name:     saga.Url
@@ -135,11 +136,11 @@ class Directory (entry.Entry) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (('Directory', st.Task))
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (('Directory', st.Task))
     def open_dir (self, path, flags=None, ttype=None) :
         '''
         :param path: name/path of the directory to open
@@ -165,11 +166,11 @@ class Directory (entry.Entry) :
     #
     # namespace directory methods
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def make_dir (self, tgt, flags=0, ttype=None) :
         '''
         :param tgt:   name/path of the new directory
@@ -193,10 +194,10 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def change_dir (self, url, ttype=None) :
         '''
         url:           saga.Url
@@ -208,11 +209,11 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional (basestring),
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.list_of (surl.Url), st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional (basestring),
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.list_of (surl.Url), st.Task))
     def list (self, pattern=None, flags=0, ttype=None) :
         '''
         :param pattern: Entry name pattern (like POSIX 'ls', e.g. '\*.txt')
@@ -235,10 +236,10 @@ class Directory (entry.Entry) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def exists (self, path, ttype=None) :
 
         '''
@@ -262,11 +263,11 @@ class Directory (entry.Entry) :
   
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional (basestring),
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.list_of (surl.Url), st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional (basestring),
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.list_of (surl.Url), st.Task))
     def find (self, pattern, flags=RECURSIVE, ttype=None) :
         '''
         pattern:       string
@@ -279,9 +280,9 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((int, st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((int, st.Task))
     def get_num_entries (self, ttype=None) :
         '''
         ttype:         saga.task.type enum
@@ -292,10 +293,10 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   int, 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((surl.Url, st.Task))
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((surl.Url, st.Task))
     def get_entry (self, num, ttype=None) :
         '''
         num:           int 
@@ -309,12 +310,12 @@ class Directory (entry.Entry) :
     #
     # methods overloaded from namespace.Entry
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def copy (self, url_1, url_2=None, flags=0, ttype=None) :
         '''
         :param src: path of the entry to copy
@@ -344,12 +345,12 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def link (self, url_1, url_2, flags=0, ttype=None) :
         '''
         src:           saga.Url
@@ -364,12 +365,12 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def move (self, url_1, url_2, flags=0, ttype=None) :
         '''
         :param src: path of the entry to copy
@@ -395,11 +396,11 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
+    @rus.takes   ('Directory', 
                   (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def remove (self, tgt, flags=0, ttype=None) :
         '''
         tgt:           saga.Url
@@ -410,13 +411,35 @@ class Directory (entry.Entry) :
         if tgt    :  return self._adaptor.remove (tgt, flags, ttype=ttype)
         else      :  return self._nsentry.remove (     flags, ttype=ttype)
   
+    # --------------------------------------------------------------------------
+    #
+    @rus.takes   ('Directory',
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
+    def remove_self (self, flags=0, ttype=None) :
+        '''
+        :param flags:  Flags to use for the operation.
+
+        ttype:         saga.task.type enum
+        ret:           None / saga.Task
+        
+        Reove the entry.
+
+        The entry is removed, and this object instance is then invalid for
+        further operations.
+
+            # remove an entry
+            entry = saga.namespace.Directory("sftp://localhost/tmp/data/data.bin")
+            entry.remove ()
+        '''
+        return self._adaptor.remove_self (flags, ttype=ttype)   
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional ((surl.Url, basestring)),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional ((surl.Url, basestring)),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def is_dir (self, tgt=None, ttype=None) :
         '''
         tgt:           saga.Url / None
@@ -438,10 +461,10 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional ((surl.Url, basestring)),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional ((surl.Url, basestring)),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def is_entry (self, tgt=None, ttype=None) :
         '''
         tgt:           saga.Url / None
@@ -454,10 +477,10 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional ((surl.Url, basestring)),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional ((surl.Url, basestring)),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def is_link (self, tgt=None, ttype=None) :
         '''
         tgt:           saga.Url / None
@@ -470,10 +493,10 @@ class Directory (entry.Entry) :
     
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('Directory', 
-                  sus.optional ((surl.Url, basestring)),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((surl.Url, st.Task))
+    @rus.takes   ('Directory', 
+                  rus.optional ((surl.Url, basestring)),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((surl.Url, st.Task))
     def read_link (self, tgt=None, ttype=None) :
         '''
         tgt:           saga.Url / None
@@ -485,5 +508,5 @@ class Directory (entry.Entry) :
         else      :  return self._nsentry.read_link (     ttype=ttype)
   
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
