@@ -1,10 +1,11 @@
 
-__author__    = "Andre Merzky"
+__author__    = "Andre Merzky, Ole Weidner"
 __copyright__ = "Copyright 2012-2013, The SAGA Project"
 __license__   = "MIT"
 
 
-import saga.utils.signatures     as sus
+import radical.utils.signatures  as rus
+
 import saga.adaptors.base        as sab
 import saga.attributes           as sa
 import saga.session              as ss
@@ -22,14 +23,14 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalDirectory', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int), 
-                  sus.optional (ss.Session),
-                  sus.optional (sab.Base), 
-                  sus.optional (dict), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (sus.nothing)
+    @rus.takes   ('LogicalDirectory', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int), 
+                  rus.optional (ss.Session),
+                  rus.optional (sab.Base), 
+                  rus.optional (dict), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (rus.nothing)
     def __init__ (self, url=None, flags=READ, session=None, 
                   _adaptor=None, _adaptor_state={}, _ttype=None) : 
         '''
@@ -54,12 +55,12 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
     # --------------------------------------------------------------------------
     #
     @classmethod
-    @sus.takes   ('LogicalDirectory', 
-                  sus.one_of (surl.Url, basestring), 
-                  sus.optional (int), 
-                  sus.optional (ss.Session),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (st.Task)
+    @rus.takes   ('LogicalDirectory', 
+                  rus.one_of (surl.Url, basestring), 
+                  rus.optional (int), 
+                  rus.optional (ss.Session),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (st.Task)
     def create (cls, url, flags=READ, session=None, ttype=None) :
         '''
         url:       saga.Url
@@ -73,10 +74,10 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
         return _nsdirec.create (url, flags, session, ttype=ttype)
 
 
-    @sus.takes   ('LogicalDirectory', 
-                  sus.one_of (surl.Url, basestring), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+    @rus.takes   ('LogicalDirectory', 
+                  rus.one_of (surl.Url, basestring), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def is_file (self, tgt=None, ttype=None) :
         '''
         is_file(tgt=None)
@@ -89,11 +90,11 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
         else       :  return self._nsdirec.is_file_self (      ttype=ttype)
 
 
-    @sus.takes   ('LogicalDirectory', 
-                  sus.one_of (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (('LogicalFile', st.Task))
+    @rus.takes   ('LogicalDirectory', 
+                  rus.one_of (surl.Url, basestring), 
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (('LogicalFile', st.Task))
     def open (self, tgt, flags=READ, ttype=None) :
         '''
         open(tgt, flags=READ)
@@ -107,11 +108,11 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
         return self._adaptor.open (tgt_url, flags, ttype=ttype)
 
 
-    @sus.takes   ('LogicalDirectory', 
-                  sus.one_of (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (('LogicalDirectory', st.Task))
+    @rus.takes   ('LogicalDirectory', 
+                  rus.one_of (surl.Url, basestring), 
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (('LogicalDirectory', st.Task))
     def open_dir (self, tgt, flags=READ, ttype=None) :
         '''
         open_dir(tgt, flags=READ)
@@ -142,10 +143,10 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
     #
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalDirectory', 
-                  sus.one_of (surl.Url, basestring),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((int, st.Task))
+    @rus.takes   ('LogicalDirectory', 
+                  rus.one_of (surl.Url, basestring),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((int, st.Task))
     def get_size (self, tgt, ttype=None) :
         '''
         get_size(tgt)
@@ -169,12 +170,12 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
         return self._adaptor.get_size (tgt_url, ttype=ttype)
 
   
-    @sus.takes   ('LogicalDirectory', 
-                  sus.optional (basestring),
-                  sus.optional (basestring),
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.list_of (surl.Url), st.Task))
+    @rus.takes   ('LogicalDirectory', 
+                  rus.optional (basestring),
+                  rus.optional (basestring),
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.list_of (surl.Url), st.Task))
     def find (self, name_pattern, attr_pattern=None, flags=RECURSIVE, ttype=None) :
         '''
         find(name_pattern, attr_pattern=None, flags=RECURSIVE)
@@ -190,5 +191,5 @@ class LogicalDirectory (nsdir.Directory, sa.Attributes) :
         else             :  return self._nsdirec.find          (name_pattern,               flags, ttype=ttype)
 
     
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
