@@ -1,10 +1,11 @@
 
-__author__    = "Andre Merzky"
+__author__    = "Andre Merzky, Ole Weidner"
 __copyright__ = "Copyright 2012-2013, The SAGA Project"
 __license__   = "MIT"
 
 
-import saga.utils.signatures     as sus
+import radical.utils.signatures  as rus
+
 import saga.adaptors.base        as sab
 import saga.attributes           as sa
 import saga.session              as ss
@@ -22,14 +23,14 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int), 
-                  sus.optional (ss.Session),
-                  sus.optional (sab.Base), 
-                  sus.optional (dict), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (sus.nothing)
+    @rus.takes   ('LogicalFile', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int), 
+                  rus.optional (ss.Session),
+                  rus.optional (sab.Base), 
+                  rus.optional (dict), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (rus.nothing)
     def __init__ (self, url=None, flags=READ, session=None, 
                   _adaptor=None, _adaptor_state={}, _ttype=None) : 
         '''
@@ -52,12 +53,12 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
     # --------------------------------------------------------------------------
     #
     @classmethod
-    @sus.takes   ('LogicalFile', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (int), 
-                  sus.optional (ss.Session),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns (st.Task)
+    @rus.takes   ('LogicalFile', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (int), 
+                  rus.optional (ss.Session),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns (st.Task)
     def create (cls, url=None, flags=READ, session=None, ttype=None) :
         '''
         url:       saga.Url
@@ -74,9 +75,9 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
 
     # ----------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((bool, st.Task))
+    @rus.takes   ('LogicalFile', 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((bool, st.Task))
     def is_file (self, ttype=None) :
         '''
         is_file()
@@ -91,9 +92,9 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
     #
     # replica methods
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((int, st.Task))
+    @rus.takes   ('LogicalFile', 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((int, st.Task))
     def get_size (self, ttype=None) :
         '''
         get_size()
@@ -119,10 +120,10 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
   
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+    @rus.takes   ('LogicalFile', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def add_location (self, name, ttype=None) :
         '''
         add_location(name)
@@ -138,10 +139,10 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+    @rus.takes   ('LogicalFile', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def remove_location (self, name, ttype=None) :
         '''
         remove_location(name)
@@ -157,11 +158,11 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional ((surl.Url, basestring)), 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+    @rus.takes   ('LogicalFile', 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional ((surl.Url, basestring)), 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def update_location (self, old, new, ttype=None) :
         '''
         update_location(old, new)
@@ -178,9 +179,9 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.list_of (surl.Url), st.Task))
+    @rus.takes   ('LogicalFile', 
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.list_of (surl.Url), st.Task))
     def list_locations (self, ttype=None) :
         '''
         list_locations()
@@ -195,11 +196,11 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
 
     # --------------------------------------------------------------------------
     #
-    @sus.takes   ('LogicalFile', 
+    @rus.takes   ('LogicalFile', 
                   (surl.Url, basestring), 
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def replicate (self, name, flags=None, ttype=None) :
         '''
         replicate(name)
@@ -217,12 +218,12 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
     # --------------------------------------------------------------------------
     # non-GFD.90
     #
-    @sus.takes   ('LogicalFile', 
+    @rus.takes   ('LogicalFile', 
                   (surl.Url, basestring), 
-                  sus.optional ((surl.Url, basestring)),
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional ((surl.Url, basestring)),
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def upload (self, name, tgt=None, flags=None, ttype=None) :
         '''
         upload(name, tgt=None, flags=None)
@@ -241,12 +242,12 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
     # --------------------------------------------------------------------------
     # non-GFD.90
     #
-    @sus.takes   ('LogicalFile', 
+    @rus.takes   ('LogicalFile', 
                   (surl.Url, basestring), 
-                  sus.optional ((surl.Url, basestring)),
-                  sus.optional (int),
-                  sus.optional (sus.one_of (SYNC, ASYNC, TASK)))
-    @sus.returns ((sus.nothing, st.Task))
+                  rus.optional ((surl.Url, basestring)),
+                  rus.optional (int),
+                  rus.optional (rus.one_of (SYNC, ASYNC, TASK)))
+    @rus.returns ((rus.nothing, st.Task))
     def download (self, name, src=None, flags=None, ttype=None) :
         '''
         download(name, src=None, flags=None)
@@ -262,5 +263,5 @@ class LogicalFile (nsentry.Entry, sa.Attributes) :
         return self._adaptor.download (name, src, flags, ttype=ttype)
     
   
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
