@@ -16,9 +16,12 @@ import select
 import signal
 import termios
 
-import saga.utils.threads   as sut
-import saga.utils.logger    as sul
-import saga.exceptions      as se
+import radical.utils         as ru
+import radical.utils.logger  as rul
+
+import saga.exceptions       as se
+
+import pty_exceptions        as ptye
 
 # --------------------------------------------------------------------
 #
@@ -92,14 +95,14 @@ class PTYProcess (object) :
         fed/drained via pty pipes.  If given as string, command is split into an
         array of strings, using :func:`shlex.split`.
 
-        :type  logger:  :class:`saga.utils.logger.Logger` instance
+        :type  logger:  :class:`radical.utils.logger.Logger` instance
         :param logger:  logger stream to send status messages to.
         """
 
         self._debug = False
 
         self.logger = logger
-        if  not  self.logger : self.logger = sul.getLogger ('PTYProcess') 
+        if  not  self.logger : self.logger = rul.getLogger ('saga', 'PTYProcess') 
         self.logger.debug ("PTYProcess init %s" % self)
 
 
@@ -112,12 +115,13 @@ class PTYProcess (object) :
         if len(command) < 1 :
             raise se.BadParameter ("PTYProcess expects non-empty command")
 
-        self.rlock   = sut.RLock ("pty process %s" % command)
+        self.rlock   = ru.RLock ("pty process %s" % command)
 
         self.command = command # list of strings too run()
 
 
         self.cache   = ""      # data cache
+        self.tail    = ""      # tail of data data cache for error messages
         self.child   = None    # the process as created by subprocess.Popen
         self.ptyio   = None    # the process' io channel, from pty.fork()
 
@@ -132,7 +136,7 @@ class PTYProcess (object) :
             self.initialize ()
 
         except Exception as e :
-            raise se.NoSuccess ("pty or process creation failed (%s)" % e)
+            raise ptye.translate_exception (e, "pty or process creation failed")
 
     # --------------------------------------------------------------------
     #
@@ -270,15 +274,26 @@ class PTYProcess (object) :
     def wait (self) :
         """ 
         blocks forever until the child finishes on its own, or is getting
-        killed
+        killed.  
+
+        Actully, we might just as well try to figure out what is going on on the
+        remote end of things -- so we read the pipe until the child dies...
         """
 
+        output = ""
+        # yes, for ever and ever...
+        while True :
+            try :
+                output += self.read ()
+            except :
+                break
+
         # yes, for ever and ever...
         while True :
 
             if not self.child:
                 # this was quick ;-)
-                return
+                return output
 
             # we need to lock, as the SIGCHLD will only arrive once
             with self.rlock :
@@ -293,10 +308,10 @@ class PTYProcess (object) :
                         self.exit_code   = None
                         self.exit_signal = None
                         self.finalize ()
-                        return
+                        return output
 
                     # no idea what happened -- it is likely bad
-                    raise se.NoSuccess ("waitpid failed: %s" % e)
+                    raise se.NoSuccess ("waitpid failed")
 
 
                 # did we get a note about child termination?
@@ -321,7 +336,7 @@ class PTYProcess (object) :
                 self.child = None
                 self.finalize (wstat=wstat)
 
-                return
+                return output
 
 
     # --------------------------------------------------------------------
@@ -349,14 +364,14 @@ class PTYProcess (object) :
             if  self.child :
 
                 while True :
-                    # print 'waitpid %s' % self.child
+                  # print 'waitpid %s' % self.child
                     # hey, kiddo, whats up?
                     wpid, wstat = os.waitpid (self.child, os.WNOHANG)
-                    # print 'waitpid %s : %s - %s' % (self.child, wpid, wstat)
+                  # print 'waitpid %s : %s - %s' % (self.child, wpid, wstat)
 
                     # did we get a note about child termination?
                     if 0 == wpid :
-                        # print 'waitpid %s : %s - %s -- none' % (self.child, wpid, wstat)
+                      # print 'waitpid %s : %s - %s -- none' % (self.child, wpid, wstat)
                         # nope, all is well - carry on
                         return True
 
@@ -365,7 +380,7 @@ class PTYProcess (object) :
                     # Well, maybe the child fooled us and is just playing dead?
                     if os.WIFSTOPPED   (wstat) or \
                        os.WIFCONTINUED (wstat)    :
-                        # print 'waitpid %s : %s - %s -- stop/cont' % (self.child, wpid, wstat)
+                      # print 'waitpid %s : %s - %s -- stop/cont' % (self.child, wpid, wstat)
                         # we don't care if someone stopped/resumed the child -- that is up
                         # to higher powers.  For our purposes, the child is alive.  Ha!
                         continue
@@ -374,13 +389,14 @@ class PTYProcess (object) :
 
                 # so its dead -- make sure it stays dead, to avoid zombie
                 # apocalypse...
+              # print "he's dead, honeybunny, jim is dead..."
                 self.child = None
                 self.finalize (wstat=wstat)
 
 
             # check if we can attempt a post-mortem revival though
             if  not recover :
-                # print 'not alive, not recover'
+              # print 'not alive, not recover'
                 # nope, we are on holy ground - revival not allowed.
                 return False
 
@@ -389,7 +405,7 @@ class PTYProcess (object) :
             # reincarnate, etc.)
             if self.recover_attempts >= self.recover_max :
                 # nope, its gone for good - just report the sad news
-                # print 'not alive, no recover anymore'
+              # print 'not alive, no recover anymore'
                 return False
 
             # MEDIIIIC!!!!
@@ -400,7 +416,7 @@ class PTYProcess (object) :
             # again.  Yes, this is recursive -- but note that recover_attempts get
             # incremented on every iteration, and this will eventually lead to
             # call termination (tm).
-            # print 'alive, or not alive?  Check again!'
+          # print 'alive, or not alive?  Check again!'
             return self.alive (recover=True)
 
 
@@ -453,11 +469,8 @@ class PTYProcess (object) :
 
             found_eof = False
 
-            if not self.alive (recover=False) :
-                if self.cache :
-                    raise se.NoSuccess ("process I/O failed: %s" % self.cache[-256:])
-                else :
-                    raise se.NoSuccess ("process I/O failed")
+            if  not self.alive (recover=False) :
+                raise se.NoSuccess ("process I/O failed: %s" % self.tail)
 
             try:
                 # start the timeout timer right now.  Note that even if timeout is
@@ -472,15 +485,19 @@ class PTYProcess (object) :
                     # first, lets see if we still have data in the cache we can return
                     if len (self.cache) :
 
-                        if not size :
-                            ret = self.cache
+                        if  not size :
+                            ret        = self.cache
                             self.cache = ""
+                            self.tail += ret
+                            self.tail  = self.tail[-256:]
                             return ret
 
                         # we don't even need all of the cache
                         elif size <= len (self.cache) :
-                            ret = self.cache[:size]
+                            ret        = self.cache[:size]
                             self.cache = self.cache[size:]
+                            self.tail += ret
+                            self.tail  = self.tail[-256:]
                             return ret
 
                     # otherwise we need to read some more data, right?
@@ -492,7 +509,7 @@ class PTYProcess (object) :
                         # read whatever we still need
 
                         readsize = _CHUNKSIZE
-                        if size: 
+                        if  size: 
                             readsize = size-len(ret)
 
                         buf  = os.read (f, _CHUNKSIZE)
@@ -501,8 +518,7 @@ class PTYProcess (object) :
                             self.logger.debug ("read : MacOS EOF")
                             self.finalize ()
                             found_eof = True
-                            raise se.NoSuccess ("unexpected EOF (%s)" \
-                                             % self.cache[-256:])
+                            raise se.NoSuccess ("unexpected EOF (%s)" % self.tail)
 
 
                         self.cache += buf.replace ('\r', '')
@@ -521,15 +537,19 @@ class PTYProcess (object) :
                     # lets see if we still got any data in the cache we can return
                     if len (self.cache) :
 
-                        if not size :
-                            ret = self.cache
+                        if  not size :
+                            ret        = self.cache
                             self.cache = ""
+                            self.tail += ret
+                            self.tail  = self.tail[-256:]
                             return ret
 
                         # we don't even need all of the cache
                         elif size <= len (self.cache) :
-                            ret = self.cache[:size]
+                            ret        = self.cache[:size]
                             self.cache = self.cache[size:]
+                            self.tail += ret
+                            self.tail  = self.tail[-256:]
                             return ret
 
                     # at this point, we do not have sufficient data -- only
@@ -540,12 +560,16 @@ class PTYProcess (object) :
                         if len (self.cache) :
                             ret        = self.cache
                             self.cache = ""
+                            self.tail += ret
+                            self.tail  = self.tail[-256:]
                             return ret
 
                     elif timeout < 0 :
                         # return of we have data or not
                         ret        = self.cache
                         self.cache = ""
+                        self.tail += ret
+                        self.tail  = self.tail[-256:]
                         return ret
 
                     else : # timeout > 0
@@ -554,16 +578,18 @@ class PTYProcess (object) :
                         if (now-start) > timeout :
                             ret        = self.cache
                             self.cache = ""
+                            self.tail += ret
+                            self.tail  = self.tail[-256:]
                             return ret
 
 
             except Exception as e :
 
-                if found_eof :
+                if  found_eof :
                     raise e
 
                 raise se.NoSuccess ("read from process failed '%s' : (%s)" \
-                                 % (e, self.cache[-256:]))
+                                 % (e, self.tail))
 
 
     # ----------------------------------------------------------------
@@ -603,7 +629,7 @@ class PTYProcess (object) :
                 data  = self.cache                         # initial data to check
                 self.cache = ""
 
-                if not data : # empty cache?
+                if  not data : # empty cache?
                     data = self.read (timeout=_POLLDELAY)
 
                 # pre-compile the given pattern, to speed up matching
@@ -617,9 +643,9 @@ class PTYProcess (object) :
                   # time.sleep (0.1)
 
                     # skip non-lines
-                    if  None == data :
+                    if  not data :
                         data += self.read (timeout=_POLLDELAY)
-                    if self._debug : print ">>%s<<" % data
+                  # if  self._debug : print ">>%s<<" % data
 
                     # check current data for any matching pattern
                     for n in range (0, len(patts)) :
@@ -655,11 +681,8 @@ class PTYProcess (object) :
                     # no match yet, still time -- read more data
                     data += self.read (timeout=_POLLDELAY)
 
-
-            except Exception as e :
-                if  issubclass (e.__class__, se.SagaException) :
-                    raise se.NoSuccess ("error (%s): %s" % (e._plain_message, data))
-                raise se.NoSuccess ("error (%s): %s" % (e, data))
+            except se.NoSuccess as e :
+                raise ptye.translate_exception (e, "(%s)" % data)
 
 
     # ----------------------------------------------------------------
@@ -673,8 +696,8 @@ class PTYProcess (object) :
         with self.rlock :
 
             if not self.alive (recover=False) :
-                raise se.NoSuccess ("cannot write to dead process (%s)" \
-                                 % self.cache[-256:])
+                raise ptye.translate_exception (se.NoSuccess ("cannot write to dead process (%s)" \
+                                                % self.cache[-256:]))
 
             try :
 
@@ -706,8 +729,8 @@ class PTYProcess (object) :
 
 
             except Exception as e :
-                raise se.NoSuccess ("write to process failed (%s)" % e)
+                raise ptye.translate_exception (e, "write to process failed (%s)" % e)
+
 
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
 
