@@ -1,5 +1,5 @@
 
-__author__    = "Andre Merzky"
+__author__    = "Andre Merzky, Ole Weidner"
 __copyright__ = "Copyright 2012-2013, The SAGA Project"
 __license__   = "MIT"
 
@@ -10,12 +10,18 @@ import sys
 import errno
 
 import saga.utils.misc              as sumisc
-import saga.utils.logger            as sul
+import radical.utils.logger         as rul
+
 import saga.utils.pty_shell_factory as supsf
 import saga.url                     as surl
 import saga.exceptions              as se
 import saga.session                 as ss
 
+import pty_exceptions               as ptye
+
+
+# ------------------------------------------------------------------------------
+#
 _PTY_TIMEOUT = 2.0
 
 # ------------------------------------------------------------------------------
@@ -174,7 +180,7 @@ class PTYShell (object) :
     def __init__ (self, url, session=None, logger=None, init=None, opts={}) :
 
         if  None != logger  : self.logger  = logger
-        else                : self.logger  = sul.getLogger ('PTYShell') 
+        else                : self.logger  = rul.getLogger ('saga', 'PTYShell') 
 
         self.logger.debug ("PTYShell init %s" % self)
 
@@ -306,7 +312,7 @@ class PTYShell (object) :
                 return self.pty_shell.alive (recover)
 
             except Exception as e :
-                raise self._translate_exception (e)
+                raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -338,7 +344,7 @@ class PTYShell (object) :
                 return (ret, txt)
 
             except Exception as e :
-                raise self._translate_exception (e)
+                raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -354,7 +360,7 @@ class PTYShell (object) :
                 return self.pty_shell.find (patterns, timeout=timeout)
 
             except Exception as e :
-                raise self._translate_exception (e)
+                raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -450,7 +456,7 @@ class PTYShell (object) :
 
                 except Exception as e :
                     self.prompt = old_prompt
-                    raise self._translate_exception (e, "Could not set shell prompt")
+                    raise ptye.translate_exception (e, "Could not set shell prompt")
 
 
             # got a valid prompt -- but we have to sync the output again in
@@ -518,7 +524,7 @@ class PTYShell (object) :
 
             except Exception as e :
                 
-                raise self._translate_exception (e, "Could not eval prompt")
+                raise ptye.translate_exception (e, "Could not eval prompt")
 
 
 
@@ -669,7 +675,7 @@ class PTYShell (object) :
                 return (ret, stdout, stderr)
 
             except Exception as e :
-                raise self._translate_exception (e)
+                raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -701,7 +707,7 @@ class PTYShell (object) :
                 self.send ("%s\n" % command)
 
             except Exception as e :
-                raise self._translate_exception (e)
+                raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -721,7 +727,7 @@ class PTYShell (object) :
                 self.pty_shell.write ("%s" % data)
 
             except Exception as e :
-                raise self._translate_exception (e)
+                raise ptye.translate_exception (e)
 
     # ----------------------------------------------------------------
     #
@@ -753,12 +759,14 @@ class PTYShell (object) :
             fhandle.flush  ()
             fhandle.close  ()
 
-            self.factory.run_copy_to (self.pty_info, fname, tgt)
+            ret = self.factory.run_copy_to (self.pty_info, fname, tgt)
 
             os.remove (fname)
 
+            return ret
+
         except Exception as e :
-            raise self._translate_exception (e)
+            raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -778,7 +786,7 @@ class PTYShell (object) :
             # first, write data into a tmp file
             fname   = self.base + "/staging.%s" % id(self)
 
-            self.factory.run_copy_from (self.pty_info, src, fname)
+            _ = self.factory.run_copy_from (self.pty_info, src, fname)
 
             fhandle = open (fname, 'r')
             out = fhandle.read  ()
@@ -789,7 +797,7 @@ class PTYShell (object) :
             return out
 
         except Exception as e :
-            raise self._translate_exception (e)
+            raise ptye.translate_exception (e)
 
 
     # ----------------------------------------------------------------
@@ -811,10 +819,10 @@ class PTYShell (object) :
         # prompt, and updating pwd state on every find_prompt.
 
         try :
-            self.factory.run_copy_to (self.pty_info, src, tgt, cp_flags)
+            return self.factory.run_copy_to (self.pty_info, src, tgt, cp_flags)
 
         except Exception as e :
-            raise self._translate_exception (e)
+            raise ptye.translate_exception (e)
 
     # ----------------------------------------------------------------
     #
@@ -835,60 +843,12 @@ class PTYShell (object) :
         # prompt, and updating pwd state on every find_prompt.
 
         try :
-            self.factory.run_copy_from (self.pty_info, src, tgt, cp_flags)
+            return self.factory.run_copy_from (self.pty_info, src, tgt, cp_flags)
 
         except Exception as e :
-            raise self._translate_exception (e)
+            raise ptye.translate_exception (e)
 
 
-    # ----------------------------------------------------------------
-    #
-    def _translate_exception (self, e, msg=None) :
-        """
-        In many cases, we should be able to roughly infer the exception cause
-        from the error message -- this is centrally done in this method.  If
-        possible, it will return a new exception with a more concise error
-        message and appropriate exception type.
-        """
-
-        if  not issubclass (e.__class__, se.SagaException) :
-            # we do not touch non-saga exceptions
-            return e
-
-        if  not issubclass (e.__class__, se.NoSuccess) :
-            # this seems to have a specific cause already, leave it alone
-            return e
-
-        cmsg = e._plain_message
-        lmsg = cmsg.lower ()
-
-        if  msg :
-            cmsg = "%s (%s)" % (cmsg, msg)
-
-        if 'auth' in lmsg :
-            e = se.AuthorizationFailed (cmsg)
-
-        elif 'pass' in lmsg :
-            e = se.AuthenticationFailed (cmsg)
-
-        elif 'ssh_exchange_identification' in lmsg :
-            e = se.AuthenticationFailed ("too frequent login attempts, or sshd misconfiguration: %s" % cmsg)
-
-        elif 'denied' in lmsg :
-            e = se.PermissionDenied (cmsg)
-
-        elif 'shared connection' in lmsg :
-            e = se.NoSuccess ("Insufficient system resources: %s" % cmsg)
-
-        elif 'pty allocation' in lmsg :
-            e = se.NoSuccess ("Insufficient system resources: %s" % cmsg)
-
-        elif 'Connection to master closed' in lmsg :
-            e = se.NoSuccess ("Connection failed (insufficient system resources?): %s" % cmsg)
-
-        # print e.traceback
-        return e
 
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
 
