@@ -12,6 +12,8 @@ from   saga.utils.singleton import Singleton
 import saga.adaptors.cpi.base
 import saga.adaptors.cpi.job
 
+import radical.utils as ru
+
 
 _ADAPTOR_NAME        = 'saga.adaptor.mock'
 _ADAPTOR_SCHEMAS     = ['mock']
@@ -58,5 +60,5 @@ class MockJob (saga.adaptors.cpi.job.Job) :
 
 
 
-# vim: tabstop=8 expandtab shiftwidth=4 softtabstop=4
+
 
